/*-
 * Copyright (C)2020..2024 @BABOLO http://www.babolo.ru/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ident "@(#) Copyright (C)2020..2024 @BABOLO http://www.babolo.ru/"
#ident "@(#) $Id: bysh.c,v 1.2 2024/01/08 00:11:11 babolo Exp $"

#include <sys/types.h>

extern const u_int16_t recobe_bysh[7][256];

/*  recobe.h recobe_bysh   const u_char recobe_bysh[7][256][2] */

const u_int16_t recobe_bysh[7][256] =
{ { 0x0000, 0x0002, 0x0004, 0x0006,   0x0008, 0x000A, 0x000C, 0x000E
  , 0x0010, 0x0012, 0x0014, 0x0016,   0x0018, 0x001A, 0x001C, 0x001E
  , 0x0020, 0x0022, 0x0024, 0x0026,   0x0028, 0x002A, 0x002C, 0x002E
  , 0x0030, 0x0032, 0x0034, 0x0036,   0x0038, 0x003A, 0x003C, 0x003E

  , 0x0040, 0x0042, 0x0044, 0x0046,   0x0048, 0x004A, 0x004C, 0x004E
  , 0x0050, 0x0052, 0x0054, 0x0056,   0x0058, 0x005A, 0x005C, 0x005E
  , 0x0060, 0x0062, 0x0064, 0x0066,   0x0068, 0x006A, 0x006C, 0x006E
  , 0x0070, 0x0072, 0x0074, 0x0076,   0x0078, 0x007A, 0x007C, 0x007E

  , 0x0080, 0x0082, 0x0084, 0x0086,   0x0088, 0x008A, 0x008C, 0x008E
  , 0x0090, 0x0092, 0x0094, 0x0096,   0x0098, 0x009A, 0x009C, 0x009E
  , 0x00A0, 0x00A2, 0x00A4, 0x00A6,   0x00A8, 0x00AA, 0x00AC, 0x00AE
  , 0x00B0, 0x00B2, 0x00B4, 0x00B6,   0x00B8, 0x00BA, 0x00BC, 0x00BE

  , 0x00C0, 0x00C2, 0x00C4, 0x00C6,   0x00C8, 0x00CA, 0x00CC, 0x00CE
  , 0x00D0, 0x00D2, 0x00D4, 0x00D6,   0x00D8, 0x00DA, 0x00DC, 0x00DE
  , 0x00E0, 0x00E2, 0x00E4, 0x00E6,   0x00E8, 0x00EA, 0x00EC, 0x00EE
  , 0x00F0, 0x00F2, 0x00F4, 0x00F6,   0x00F8, 0x00FA, 0x00FC, 0x00FE

  , 0x0100, 0x0102, 0x0104, 0x0106,   0x0108, 0x010A, 0x010C, 0x010E
  , 0x0110, 0x0112, 0x0114, 0x0116,   0x0118, 0x011A, 0x011C, 0x011E
  , 0x0120, 0x0122, 0x0124, 0x0126,   0x0128, 0x012A, 0x012C, 0x012E
  , 0x0130, 0x0132, 0x0134, 0x0136,   0x0138, 0x013A, 0x013C, 0x013E

  , 0x0140, 0x0142, 0x0144, 0x0146,   0x0148, 0x014A, 0x014C, 0x014E
  , 0x0150, 0x0152, 0x0154, 0x0156,   0x0158, 0x015A, 0x015C, 0x015E
  , 0x0160, 0x0162, 0x0164, 0x0166,   0x0168, 0x016A, 0x016C, 0x016E
  , 0x0170, 0x0172, 0x0174, 0x0176,   0x0178, 0x017A, 0x017C, 0x017E

  , 0x0180, 0x0182, 0x0184, 0x0186,   0x0188, 0x018A, 0x018C, 0x018E
  , 0x0190, 0x0192, 0x0194, 0x0196,   0x0198, 0x019A, 0x019C, 0x019E
  , 0x01A0, 0x01A2, 0x01A4, 0x01A6,   0x01A8, 0x01AA, 0x01AC, 0x01AE
  , 0x01B0, 0x01B2, 0x01B4, 0x01B6,   0x01B8, 0x01BA, 0x01BC, 0x01BE

  , 0x01C0, 0x01C2, 0x01C4, 0x01C6,   0x01C8, 0x01CA, 0x01CC, 0x01CE
  , 0x01D0, 0x01D2, 0x01D4, 0x01D6,   0x01D8, 0x01DA, 0x01DC, 0x01DE
  , 0x01E0, 0x01E2, 0x01E4, 0x01E6,   0x01E8, 0x01EA, 0x01EC, 0x01EE
  , 0x01F0, 0x01F2, 0x01F4, 0x01F6,   0x01F8, 0x01FA, 0x01FC, 0x01FE
  }

, { 0x0000, 0x0004, 0x0008, 0x000C,   0x0010, 0x0014, 0x0018, 0x001C
  , 0x0020, 0x0024, 0x0028, 0x002C,   0x0030, 0x0034, 0x0038, 0x003C
  , 0x0040, 0x0044, 0x0048, 0x004C,   0x0050, 0x0054, 0x0058, 0x005C
  , 0x0060, 0x0064, 0x0068, 0x006C,   0x0070, 0x0074, 0x0078, 0x007C

  , 0x0080, 0x0084, 0x0088, 0x008C,   0x0090, 0x0094, 0x0098, 0x009C
  , 0x00A0, 0x00A4, 0x00A8, 0x00AC,   0x00B0, 0x00B4, 0x00B8, 0x00BC
  , 0x00C0, 0x00C4, 0x00C8, 0x00CC,   0x00D0, 0x00D4, 0x00D8, 0x00DC
  , 0x00E0, 0x00E4, 0x00E8, 0x00EC,   0x00F0, 0x00F4, 0x00F8, 0x00FC

  , 0x0100, 0x0104, 0x0108, 0x010C,   0x0110, 0x0114, 0x0118, 0x011C
  , 0x0120, 0x0124, 0x0128, 0x012C,   0x0130, 0x0134, 0x0138, 0x013C
  , 0x0140, 0x0144, 0x0148, 0x014C,   0x0150, 0x0154, 0x0158, 0x015C
  , 0x0160, 0x0164, 0x0168, 0x016C,   0x0170, 0x0174, 0x0178, 0x017C

  , 0x0180, 0x0184, 0x0188, 0x018C,   0x0190, 0x0194, 0x0198, 0x019C
  , 0x01A0, 0x01A4, 0x01A8, 0x01AC,   0x01B0, 0x01B4, 0x01B8, 0x01BC
  , 0x01C0, 0x01C4, 0x01C8, 0x01CC,   0x01D0, 0x01D4, 0x01D8, 0x01DC
  , 0x01E0, 0x01E4, 0x01E8, 0x01EC,   0x01F0, 0x01F4, 0x01F8, 0x01FC

  , 0x0200, 0x0204, 0x0208, 0x020C,   0x0210, 0x0214, 0x0218, 0x021C
  , 0x0220, 0x0224, 0x0228, 0x022C,   0x0230, 0x0234, 0x0238, 0x023C
  , 0x0240, 0x0244, 0x0248, 0x024C,   0x0250, 0x0254, 0x0258, 0x025C
  , 0x0260, 0x0264, 0x0268, 0x026C,   0x0270, 0x0274, 0x0278, 0x027C

  , 0x0280, 0x0284, 0x0288, 0x028C,   0x0290, 0x0294, 0x0298, 0x029C
  , 0x02A0, 0x02A4, 0x02A8, 0x02AC,   0x02B0, 0x02B4, 0x02B8, 0x02BC
  , 0x02C0, 0x02C4, 0x02C8, 0x02CC,   0x02D0, 0x02D4, 0x02D8, 0x02DC
  , 0x02E0, 0x02E4, 0x02E8, 0x02EC,   0x02F0, 0x02F4, 0x02F8, 0x02FC

  , 0x0300, 0x0304, 0x0308, 0x030C,   0x0310, 0x0314, 0x0318, 0x031C
  , 0x0320, 0x0324, 0x0328, 0x032C,   0x0330, 0x0334, 0x0338, 0x033C
  , 0x0340, 0x0344, 0x0348, 0x034C,   0x0350, 0x0354, 0x0358, 0x035C
  , 0x0360, 0x0364, 0x0368, 0x036C,   0x0370, 0x0374, 0x0378, 0x037C

  , 0x0380, 0x0384, 0x0388, 0x038C,   0x0390, 0x0394, 0x0398, 0x039C
  , 0x03A0, 0x03A4, 0x03A8, 0x03AC,   0x03B0, 0x03B4, 0x03B8, 0x03BC
  , 0x03C0, 0x03C4, 0x03C8, 0x03CC,   0x03D0, 0x03D4, 0x03D8, 0x03DC
  , 0x03E0, 0x03E4, 0x03E8, 0x03EC,   0x03F0, 0x03F4, 0x03F8, 0x03FC
  }

, { 0x0000, 0x0008, 0x0010, 0x0018,   0x0020, 0x0028, 0x0030, 0x0038
  , 0x0040, 0x0048, 0x0050, 0x0058,   0x0060, 0x0068, 0x0070, 0x0078
  , 0x0080, 0x0088, 0x0090, 0x0098,   0x00A0, 0x00A8, 0x00B0, 0x00B8
  , 0x00C0, 0x00C8, 0x00D0, 0x00D8,   0x00E0, 0x00E8, 0x00F0, 0x00F8

  , 0x0100, 0x0108, 0x0110, 0x0118,   0x0120, 0x0128, 0x0130, 0x0138
  , 0x0140, 0x0148, 0x0150, 0x0158,   0x0160, 0x0168, 0x0170, 0x0178
  , 0x0180, 0x0188, 0x0190, 0x0198,   0x01A0, 0x01A8, 0x01B0, 0x01B8
  , 0x01C0, 0x01C8, 0x01D0, 0x01D8,   0x01E0, 0x01E8, 0x01F0, 0x01F8

  , 0x0200, 0x0208, 0x0210, 0x0218,   0x0220, 0x0228, 0x0230, 0x0238
  , 0x0240, 0x0248, 0x0250, 0x0258,   0x0260, 0x0268, 0x0270, 0x0278
  , 0x0280, 0x0288, 0x0290, 0x0298,   0x02A0, 0x02A8, 0x02B0, 0x02B8
  , 0x02C0, 0x02C8, 0x02D0, 0x02D8,   0x02E0, 0x02E8, 0x02F0, 0x02F8

  , 0x0300, 0x0308, 0x0310, 0x0318,   0x0320, 0x0328, 0x0330, 0x0338
  , 0x0340, 0x0348, 0x0350, 0x0358,   0x0360, 0x0368, 0x0370, 0x0378
  , 0x0380, 0x0388, 0x0390, 0x0398,   0x03A0, 0x03A8, 0x03B0, 0x03B8
  , 0x03C0, 0x03C8, 0x03D0, 0x03D8,   0x03E0, 0x03E8, 0x03F0, 0x03F8

  , 0x0400, 0x0408, 0x0410, 0x0418,   0x0420, 0x0428, 0x0430, 0x0438
  , 0x0440, 0x0448, 0x0450, 0x0458,   0x0460, 0x0468, 0x0470, 0x0478
  , 0x0480, 0x0488, 0x0490, 0x0498,   0x04A0, 0x04A8, 0x04B0, 0x04B8
  , 0x04C0, 0x04C8, 0x04D0, 0x04D8,   0x04E0, 0x04E8, 0x04F0, 0x04F8

  , 0x0500, 0x0508, 0x0510, 0x0518,   0x0520, 0x0528, 0x0530, 0x0538
  , 0x0540, 0x0548, 0x0550, 0x0558,   0x0560, 0x0568, 0x0570, 0x0578
  , 0x0580, 0x0588, 0x0590, 0x0598,   0x05A0, 0x05A8, 0x05B0, 0x05B8
  , 0x05C0, 0x05C8, 0x05D0, 0x05D8,   0x05E0, 0x05E8, 0x05F0, 0x05F8

  , 0x0600, 0x0608, 0x0610, 0x0618,   0x0620, 0x0628, 0x0630, 0x0638
  , 0x0640, 0x0648, 0x0650, 0x0658,   0x0660, 0x0668, 0x0670, 0x0678
  , 0x0680, 0x0688, 0x0690, 0x0698,   0x06A0, 0x06A8, 0x06B0, 0x06B8
  , 0x06C0, 0x06C8, 0x06D0, 0x06D8,   0x06E0, 0x06E8, 0x06F0, 0x06F8

  , 0x0700, 0x0708, 0x0710, 0x0718,   0x0720, 0x0728, 0x0730, 0x0738
  , 0x0740, 0x0748, 0x0750, 0x0758,   0x0760, 0x0768, 0x0770, 0x0778
  , 0x0780, 0x0788, 0x0790, 0x0798,   0x07A0, 0x07A8, 0x07B0, 0x07B8
  , 0x07C0, 0x07C8, 0x07D0, 0x07D8,   0x07E0, 0x07E8, 0x07F0, 0x07F8
  }

, { 0x0000, 0x0010, 0x0020, 0x0030,   0x0040, 0x0050, 0x0060, 0x0070
  , 0x0080, 0x0090, 0x00A0, 0x00B0,   0x00C0, 0x00D0, 0x00E0, 0x00F0
  , 0x0100, 0x0110, 0x0120, 0x0130,   0x0140, 0x0150, 0x0160, 0x0170
  , 0x0180, 0x0190, 0x01A0, 0x01B0,   0x01C0, 0x01D0, 0x01E0, 0x01F0

  , 0x0200, 0x0210, 0x0220, 0x0230,   0x0240, 0x0250, 0x0260, 0x0270
  , 0x0280, 0x0290, 0x02A0, 0x02B0,   0x02C0, 0x02D0, 0x02E0, 0x02F0
  , 0x0300, 0x0310, 0x0320, 0x0330,   0x0340, 0x0350, 0x0360, 0x0370
  , 0x0380, 0x0390, 0x03A0, 0x03B0,   0x03C0, 0x03D0, 0x03E0, 0x03F0

  , 0x0400, 0x0410, 0x0420, 0x0430,   0x0440, 0x0450, 0x0460, 0x0470
  , 0x0480, 0x0490, 0x04A0, 0x04B0,   0x04C0, 0x04D0, 0x04E0, 0x04F0
  , 0x0500, 0x0510, 0x0520, 0x0530,   0x0540, 0x0550, 0x0560, 0x0570
  , 0x0580, 0x0590, 0x05A0, 0x05B0,   0x05C0, 0x05D0, 0x05E0, 0x05F0

  , 0x0600, 0x0610, 0x0620, 0x0630,   0x0640, 0x0650, 0x0660, 0x0670
  , 0x0680, 0x0690, 0x06A0, 0x06B0,   0x06C0, 0x06D0, 0x06E0, 0x06F0
  , 0x0700, 0x0710, 0x0720, 0x0730,   0x0740, 0x0750, 0x0760, 0x0770
  , 0x0780, 0x0790, 0x07A0, 0x07B0,   0x07C0, 0x07D0, 0x07E0, 0x07F0

  , 0x0800, 0x0810, 0x0820, 0x0830,   0x0840, 0x0850, 0x0860, 0x0870
  , 0x0880, 0x0890, 0x08A0, 0x08B0,   0x08C0, 0x08D0, 0x08E0, 0x08F0
  , 0x0900, 0x0910, 0x0920, 0x0930,   0x0940, 0x0950, 0x0960, 0x0970
  , 0x0980, 0x0990, 0x09A0, 0x09B0,   0x09C0, 0x09D0, 0x09E0, 0x09F0

  , 0x0A00, 0x0A10, 0x0A20, 0x0A30,   0x0A40, 0x0A50, 0x0A60, 0x0A70
  , 0x0A80, 0x0A90, 0x0AA0, 0x0AB0,   0x0AC0, 0x0AD0, 0x0AE0, 0x0AF0
  , 0x0B00, 0x0B10, 0x0B20, 0x0B30,   0x0B40, 0x0B50, 0x0B60, 0x0B70
  , 0x0B80, 0x0B90, 0x0BA0, 0x0BB0,   0x0BC0, 0x0BD0, 0x0BE0, 0x0BF0

  , 0x0C00, 0x0C10, 0x0C20, 0x0C30,   0x0C40, 0x0C50, 0x0C60, 0x0C70
  , 0x0C80, 0x0C90, 0x0CA0, 0x0CB0,   0x0CC0, 0x0CD0, 0x0CE0, 0x0CF0
  , 0x0D00, 0x0D10, 0x0D20, 0x0D30,   0x0D40, 0x0D50, 0x0D60, 0x0D70
  , 0x0D80, 0x0D90, 0x0DA0, 0x0DB0,   0x0DC0, 0x0DD0, 0x0DE0, 0x0DF0

  , 0x0E00, 0x0E10, 0x0E20, 0x0E30,   0x0E40, 0x0E50, 0x0E60, 0x0E70
  , 0x0E80, 0x0E90, 0x0EA0, 0x0EB0,   0x0EC0, 0x0ED0, 0x0EE0, 0x0EF0
  , 0x0F00, 0x0F10, 0x0F20, 0x0F30,   0x0F40, 0x0F50, 0x0F60, 0x0F70
  , 0x0F80, 0x0F90, 0x0FA0, 0x0FB0,   0x0FC0, 0x0FD0, 0x0FE0, 0x0FF0
  }

, { 0x0000, 0x0020, 0x0040, 0x0060,   0x0080, 0x00A0, 0x00C0, 0x00E0
  , 0x0100, 0x0120, 0x0140, 0x0160,   0x0180, 0x01A0, 0x01C0, 0x01E0
  , 0x0200, 0x0220, 0x0240, 0x0260,   0x0280, 0x02A0, 0x02C0, 0x02E0
  , 0x0300, 0x0320, 0x0340, 0x0360,   0x0380, 0x03A0, 0x03C0, 0x03E0

  , 0x0400, 0x0420, 0x0440, 0x0460,   0x0480, 0x04A0, 0x04C0, 0x04E0
  , 0x0500, 0x0520, 0x0540, 0x0560,   0x0580, 0x05A0, 0x05C0, 0x05E0
  , 0x0600, 0x0620, 0x0640, 0x0660,   0x0680, 0x06A0, 0x06C0, 0x06E0
  , 0x0700, 0x0720, 0x0740, 0x0760,   0x0780, 0x07A0, 0x07C0, 0x07E0

  , 0x0800, 0x0820, 0x0840, 0x0860,   0x0880, 0x08A0, 0x08C0, 0x08E0
  , 0x0900, 0x0920, 0x0940, 0x0960,   0x0980, 0x09A0, 0x09C0, 0x09E0
  , 0x0A00, 0x0A20, 0x0A40, 0x0A60,   0x0A80, 0x0AA0, 0x0AC0, 0x0AE0
  , 0x0B00, 0x0B20, 0x0B40, 0x0B60,   0x0B80, 0x0BA0, 0x0BC0, 0x0BE0

  , 0x0C00, 0x0C20, 0x0C40, 0x0C60,   0x0C80, 0x0CA0, 0x0CC0, 0x0CE0
  , 0x0D00, 0x0D20, 0x0D40, 0x0D60,   0x0D80, 0x0DA0, 0x0DC0, 0x0DE0
  , 0x0E00, 0x0E20, 0x0E40, 0x0E60,   0x0E80, 0x0EA0, 0x0EC0, 0x0EE0
  , 0x0F00, 0x0F20, 0x0F40, 0x0F60,   0x0F80, 0x0FA0, 0x0FC0, 0x0FE0

  , 0x1000, 0x1020, 0x1040, 0x1060,   0x1080, 0x10A0, 0x10C0, 0x10E0
  , 0x1100, 0x1120, 0x1140, 0x1160,   0x1180, 0x11A0, 0x11C0, 0x11E0
  , 0x1200, 0x1220, 0x1240, 0x1260,   0x1280, 0x12A0, 0x12C0, 0x12E0
  , 0x1300, 0x1320, 0x1340, 0x1360,   0x1380, 0x13A0, 0x13C0, 0x13E0

  , 0x1400, 0x1420, 0x1440, 0x1460,   0x1480, 0x14A0, 0x14C0, 0x14E0
  , 0x1500, 0x1520, 0x1540, 0x1560,   0x1580, 0x15A0, 0x15C0, 0x15E0
  , 0x1600, 0x1620, 0x1640, 0x1660,   0x1680, 0x16A0, 0x16C0, 0x16E0
  , 0x1700, 0x1720, 0x1740, 0x1760,   0x1780, 0x17A0, 0x17C0, 0x17E0

  , 0x1800, 0x1820, 0x1840, 0x1860,   0x1880, 0x18A0, 0x18C0, 0x18E0
  , 0x1900, 0x1920, 0x1940, 0x1960,   0x1980, 0x19A0, 0x19C0, 0x19E0
  , 0x1A00, 0x1A20, 0x1A40, 0x1A60,   0x1A80, 0x1AA0, 0x1AC0, 0x1AE0
  , 0x1B00, 0x1B20, 0x1B40, 0x1B60,   0x1B80, 0x1BA0, 0x1BC0, 0x1BE0

  , 0x1C00, 0x1C20, 0x1C40, 0x1C60,   0x1C80, 0x1CA0, 0x1CC0, 0x1CE0
  , 0x1D00, 0x1D20, 0x1D40, 0x1D60,   0x1D80, 0x1DA0, 0x1DC0, 0x1DE0
  , 0x1E00, 0x1E20, 0x1E40, 0x1E60,   0x1E80, 0x1EA0, 0x1EC0, 0x1EE0
  , 0x1F00, 0x1F20, 0x1F40, 0x1F60,   0x1F80, 0x1FA0, 0x1FC0, 0x1FE0
  }

, { 0x0000, 0x0040, 0x0080, 0x00C0,   0x0100, 0x0140, 0x0180, 0x01C0
  , 0x0200, 0x0240, 0x0280, 0x02C0,   0x0300, 0x0340, 0x0380, 0x03C0
  , 0x0400, 0x0440, 0x0480, 0x04C0,   0x0500, 0x0540, 0x0580, 0x05C0
  , 0x0600, 0x0640, 0x0680, 0x06C0,   0x0700, 0x0740, 0x0780, 0x07C0

  , 0x0800, 0x0840, 0x0880, 0x08C0,   0x0900, 0x0940, 0x0980, 0x09C0
  , 0x0A00, 0x0A40, 0x0A80, 0x0AC0,   0x0B00, 0x0B40, 0x0B80, 0x0BC0
  , 0x0C00, 0x0C40, 0x0C80, 0x0CC0,   0x0D00, 0x0D40, 0x0D80, 0x0DC0
  , 0x0E00, 0x0E40, 0x0E80, 0x0EC0,   0x0F00, 0x0F40, 0x0F80, 0x0FC0

  , 0x1000, 0x1040, 0x1080, 0x10C0,   0x1100, 0x1140, 0x1180, 0x11C0
  , 0x1200, 0x1240, 0x1280, 0x12C0,   0x1300, 0x1340, 0x1380, 0x13C0
  , 0x1400, 0x1440, 0x1480, 0x14C0,   0x1500, 0x1540, 0x1580, 0x15C0
  , 0x1600, 0x1640, 0x1680, 0x16C0,   0x1700, 0x1740, 0x1780, 0x17C0

  , 0x1800, 0x1840, 0x1880, 0x18C0,   0x1900, 0x1940, 0x1980, 0x19C0
  , 0x1A00, 0x1A40, 0x1A80, 0x1AC0,   0x1B00, 0x1B40, 0x1B80, 0x1BC0
  , 0x1C00, 0x1C40, 0x1C80, 0x1CC0,   0x1D00, 0x1D40, 0x1D80, 0x1DC0
  , 0x1E00, 0x1E40, 0x1E80, 0x1EC0,   0x1F00, 0x1F40, 0x1F80, 0x1FC0

  , 0x2000, 0x2040, 0x2080, 0x20C0,   0x2100, 0x2140, 0x2180, 0x21C0
  , 0x2200, 0x2240, 0x2280, 0x22C0,   0x2300, 0x2340, 0x2380, 0x23C0
  , 0x2400, 0x2440, 0x2480, 0x24C0,   0x2500, 0x2540, 0x2580, 0x25C0
  , 0x2600, 0x2640, 0x2680, 0x26C0,   0x2700, 0x2740, 0x2780, 0x27C0

  , 0x2800, 0x2840, 0x2880, 0x28C0,   0x2900, 0x2940, 0x2980, 0x29C0
  , 0x2A00, 0x2A40, 0x2A80, 0x2AC0,   0x2B00, 0x2B40, 0x2B80, 0x2BC0
  , 0x2C00, 0x2C40, 0x2C80, 0x2CC0,   0x2D00, 0x2D40, 0x2D80, 0x2DC0
  , 0x2E00, 0x2E40, 0x2E80, 0x2EC0,   0x2F00, 0x2F40, 0x2F80, 0x2FC0

  , 0x3000, 0x3040, 0x3080, 0x30C0,   0x3100, 0x3140, 0x3180, 0x31C0
  , 0x3200, 0x3240, 0x3280, 0x32C0,   0x3300, 0x3340, 0x3380, 0x33C0
  , 0x3400, 0x3440, 0x3480, 0x34C0,   0x3500, 0x3540, 0x3580, 0x35C0
  , 0x3600, 0x3640, 0x3680, 0x36C0,   0x3700, 0x3740, 0x3780, 0x37C0

  , 0x3800, 0x3840, 0x3880, 0x38C0,   0x3900, 0x3940, 0x3980, 0x39C0
  , 0x3A00, 0x3A40, 0x3A80, 0x3AC0,   0x3B00, 0x3B40, 0x3B80, 0x3BC0
  , 0x3C00, 0x3C40, 0x3C80, 0x3CC0,   0x3D00, 0x3D40, 0x3D80, 0x3DC0
  , 0x3E00, 0x3E40, 0x3E80, 0x3EC0,   0x3F00, 0x3F40, 0x3F80, 0x3FC0
  }

, { 0x0000, 0x0080, 0x0100, 0x0180,   0x0200, 0x0280, 0x0300, 0x0380
  , 0x0400, 0x0480, 0x0500, 0x0580,   0x0600, 0x0680, 0x0700, 0x0780
  , 0x0800, 0x0880, 0x0900, 0x0980,   0x0A00, 0x0A80, 0x0B00, 0x0B80
  , 0x0C00, 0x0C80, 0x0D00, 0x0D80,   0x0E00, 0x0E80, 0x0F00, 0x0F80

  , 0x1000, 0x1080, 0x1100, 0x1180,   0x1200, 0x1280, 0x1300, 0x1380
  , 0x1400, 0x1480, 0x1500, 0x1580,   0x1600, 0x1680, 0x1700, 0x1780
  , 0x1800, 0x1880, 0x1900, 0x1980,   0x1A00, 0x1A80, 0x1B00, 0x1B80
  , 0x1C00, 0x1C80, 0x1D00, 0x1D80,   0x1E00, 0x1E80, 0x1F00, 0x1F80

  , 0x2000, 0x2080, 0x2100, 0x2180,   0x2200, 0x2280, 0x2300, 0x2380
  , 0x2400, 0x2480, 0x2500, 0x2580,   0x2600, 0x2680, 0x2700, 0x2780
  , 0x2800, 0x2880, 0x2900, 0x2980,   0x2A00, 0x2A80, 0x2B00, 0x2B80
  , 0x2C00, 0x2C80, 0x2D00, 0x2D80,   0x2E00, 0x2E80, 0x2F00, 0x2F80

  , 0x3000, 0x3080, 0x3100, 0x3180,   0x3200, 0x3280, 0x3300, 0x3380
  , 0x3400, 0x3480, 0x3500, 0x3580,   0x3600, 0x3680, 0x3700, 0x3780
  , 0x3800, 0x3880, 0x3900, 0x3980,   0x3A00, 0x3A80, 0x3B00, 0x3B80
  , 0x3C00, 0x3C80, 0x3D00, 0x3D80,   0x3E00, 0x3E80, 0x3F00, 0x3F80

  , 0x4000, 0x4080, 0x4100, 0x4180,   0x4200, 0x4280, 0x4300, 0x4380
  , 0x4400, 0x4480, 0x4500, 0x4580,   0x4600, 0x4680, 0x4700, 0x4780
  , 0x4800, 0x4880, 0x4900, 0x4980,   0x4A00, 0x4A80, 0x4B00, 0x4B80
  , 0x4C00, 0x4C80, 0x4D00, 0x4D80,   0x4E00, 0x4E80, 0x4F00, 0x4F80

  , 0x5000, 0x5080, 0x5100, 0x5180,   0x5200, 0x5280, 0x5300, 0x5380
  , 0x5400, 0x5480, 0x5500, 0x5580,   0x5600, 0x5680, 0x5700, 0x5780
  , 0x5800, 0x5880, 0x5900, 0x5980,   0x5A00, 0x5A80, 0x5B00, 0x5B80
  , 0x5C00, 0x5C80, 0x5D00, 0x5D80,   0x5E00, 0x5E80, 0x5F00, 0x5F80

  , 0x6000, 0x6080, 0x6100, 0x6180,   0x6200, 0x6280, 0x6300, 0x6380
  , 0x6400, 0x6480, 0x6500, 0x6580,   0x6600, 0x6680, 0x6700, 0x6780
  , 0x6800, 0x6880, 0x6900, 0x6980,   0x6A00, 0x6A80, 0x6B00, 0x6B80
  , 0x6C00, 0x6C80, 0x6D00, 0x6D80,   0x6E00, 0x6E80, 0x6F00, 0x6F80

  , 0x7000, 0x7080, 0x7100, 0x7180,   0x7200, 0x7280, 0x7300, 0x7380
  , 0x7400, 0x7480, 0x7500, 0x7580,   0x7600, 0x7680, 0x7700, 0x7780
  , 0x7800, 0x7880, 0x7900, 0x7980,   0x7A00, 0x7A80, 0x7B00, 0x7B80
  , 0x7C00, 0x7C80, 0x7D00, 0x7D80,   0x7E00, 0x7E80, 0x7F00, 0x7F80
} }
;
